@@ -29,6 +29,9 @@ FAILEDOPERATION_ACCOUNTALREADYEXISTS = 'FailedOperation.AccountAlreadyExists'
 # 账号为当前用户
 FAILEDOPERATION_ACCOUNTISYOURSELF = 'FailedOperation.AccountIsYourSelf'
 
+# 该实例 `ins-xxxxxxx` 已经在 `dgroup-xxxxxx` 置放群组里。
+FAILEDOPERATION_ALREADYINDISASTERRECOVERGROUP = 'FailedOperation.AlreadyInDisasterRecoverGroup'
+
 # 自带许可镜像暂时不支持共享。
 FAILEDOPERATION_BYOLIMAGESHAREFAILED = 'FailedOperation.BYOLImageShareFailed'
 
@@ -869,6 +872,9 @@ UNSUPPORTEDOPERATION_ARMARCHITECTURE = 'UnsupportedOperation.ArmArchitecture'
 # 指定的实例付费模式或者网络付费模式不支持共享带宽包
 UNSUPPORTEDOPERATION_BANDWIDTHPACKAGEIDNOTSUPPORTED = 'UnsupportedOperation.BandwidthPackageIdNotSupported'
 
+# cbs远端ssd盘不支持该操作
+UNSUPPORTEDOPERATION_CBSREMOTESSDNOTSUPPORT = 'UnsupportedOperation.CbsRemoteSsdNotSupport'
+
 # 实例创建快照的时间距今不到24小时。
 UNSUPPORTEDOPERATION_DISKSNAPCREATETIMETOOOLD = 'UnsupportedOperation.DiskSnapCreateTimeTooOld'
 
@@ -983,6 +989,12 @@ UNSUPPORTEDOPERATION_INSTANCESTATETERMINATED = 'UnsupportedOperation.InstanceSta
 # 请求不支持正在销毁的实例
 UNSUPPORTEDOPERATION_INSTANCESTATETERMINATING = 'UnsupportedOperation.InstanceStateTerminating'
 
+# 实例类型不支持设置`GridDriverService` 状态
+UNSUPPORTEDOPERATION_INSTANCETYPENOTSUPPORTGRIDLICENCE = 'UnsupportedOperation.InstanceTypeNotSupportGridLicence'
+
+# 实例类型不支持设置 HighDensityMode 状态
+UNSUPPORTEDOPERATION_INSTANCETYPENOTSUPPORTHIGHDENSITYMODESETTING = 'UnsupportedOperation.InstanceTypeNotSupportHighDensityModeSetting'
+
 # 实例类型不支持设置`EnableJumboFrame` 状态
 UNSUPPORTEDOPERATION_INSTANCETYPENOTSUPPORTJUMBOFRAME = 'UnsupportedOperation.InstanceTypeNotSupportJumboFrame'
 
@@ -1019,6 +1031,9 @@ UNSUPPORTEDOPERATION_INVALIDINSTANCEWITHSWAPDISK = 'UnsupportedOperation.Invalid
 # 用户无权限操作当前实例。
 UNSUPPORTEDOPERATION_INVALIDINSTANCESOWNER = 'UnsupportedOperation.InvalidInstancesOwner'
 
+# 当前操作只支持国际版用户。
+UNSUPPORTEDOPERATION_INVALIDPERMISSIONNONINTERNATIONALACCOUNT = 'UnsupportedOperation.InvalidPermissionNonInternationalAccount'
+
 # 指定的地域不支持加密盘。
 UNSUPPORTEDOPERATION_INVALIDREGIONDISKENCRYPT = 'UnsupportedOperation.InvalidRegionDiskEncrypt'
 
@@ -1097,6 +1112,12 @@ UNSUPPORTEDOPERATION_REDHATINSTANCEUNSUPPORTED = 'UnsupportedOperation.RedHatIns
 # 不支持该地域
 UNSUPPORTEDOPERATION_REGION = 'UnsupportedOperation.Region'
 
+# 当前用户暂不支持购买预留实例计费。
+UNSUPPORTEDOPERATION_RESERVEDINSTANCEINVISIBLEFORUSER = 'UnsupportedOperation.ReservedInstanceInvisibleForUser'
+
+# 用户预留实例计费配额已达上限。
+UNSUPPORTEDOPERATION_RESERVEDINSTANCEOUTOFQUATA = 'UnsupportedOperation.ReservedInstanceOutofQuata'
+
 # 共享镜像不支持导出。
 UNSUPPORTEDOPERATION_SHAREDIMAGEEXPORTUNSUPPORTED = 'UnsupportedOperation.SharedImageExportUnsupported'
 
